@@ -1,6 +1,7 @@
 from ._version import __version__
-from .map import EOxMap
+from .chart import EOxChart
 from .layercontrol import EOxLayerControl
+from .map import EOxMap
 from .layouts import EOxMapWithControl
 
-__all__ = ["EOxMap", "EOxLayerControl", "EOxMapWithControl"]
\ No newline at end of file
+__all__ = ["EOxChart", "EOxLayerControl", "EOxMap", "EOxMapWithControl"]
\ No newline at end of file
